@@ -1,7 +1,7 @@
 # -----------------------------------------------------------------------------
 #  Set CLASSPATH and Java options
 #
-#  $Id: setclasspath.sh,v 1.13 2004/07/26 21:29:42 markt Exp $
+#  $Id: setclasspath.sh,v 1.7.2.1 2004/08/21 15:49:50 yoavs Exp $
 # -----------------------------------------------------------------------------
 
 # Read $JAVA_HOME - sudo doesn't pass environment variables
@@ -61,7 +61,7 @@ fi
 
 # Set standard commands for invoking Java.
 _RUNJAVA="$JAVA_HOME"/bin/java
-if [ ! "$os400" ]; then
+if [ $os400 = false ]; then
   _RUNJDB="$JAVA_HOME"/bin/jdb
 fi
 _RUNJAVAC="$JAVA_HOME"/bin/javac
